#!/usr/bin/env bash
set -e
echo 'Starting installation'

echo 'Installing Depending Repositories...'
echo 'Installing RPMFusion'
sudo dnf install -y \
    https://download1.rpmfusion.org/free/fedora/rpmfusion-free-release-$(rpm -E %fedora).noarch.rpm \
    https://download1.rpmfusion.org/nonfree/fedora/rpmfusion-nonfree-release-$(rpm -E %fedora).noarch.rpm

echo 'Adding Flatpak'
sudo dnf install -y flatpak
sudo flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo

echo 'Enabling Cisco openh264'
sudo dnf config-manager --set-enabled fedora-cisco-openh264

echo 'Installing base packages...'
sudo dnf install -y \
    git tar zsh ack mlocate usbutils neofetch which util-linux-user vim-enhanced

echo 'Installing fonts'
sudo dnf install -y \
    twitter-twemoji-fonts fontawesome-fonts powerline-fonts

#echo 'Install fancy programming stuff...'
#sudo dnf install -y \
#    podman \
#    tig \
#    php-cli php-json php-mysqli php-zip php-xml php-mbstring php-xdebug mysql wp-cli composer java

echo 'Install locale...'
sudo dnf install -y \
    langpacks-de langpacks-en

echo 'Install my desktop stuff...'
sudo dnf install -y \
    @base-x awesome picom slock imv ibus dbus-x11 pipewire pipewire-pulseaudio dex-autostart pavucontrol alsa-utils

echo 'Installing graphical applications...'
sudo dnf install -y \
    guake firefox keepassxc nextcloud-client

echo 'Installing extended graphical applications...'
sudo dnf install -y \
    emacs gparted thunderbird filezilla telegram-desktop libreoffice \
    flameshot ibus-uniemoji xsel mpv xt7-player-mpv

#echo 'Install work packages'
#sudo dnf install -y \
#    apache-ant pedit \

# Docker and Teamviewer are still a problem on Fedora 32
# sudo dnf install -y \
#     docker-ce docker-compose \
#     teamviewer

# Install gaming
#sudo dnf install -y \
#    steam lutris gamemode

cd ~
mkdir workspace
cd workspace
git clone https://git.doggoat.de/dhalucario/devconf.git
git submodule update --init --recusive
cd devconf
./install-light.sh

mkdir ~/bin/

sudo usermod -aG audio,input $(whoami)

vim +PlugInstall +qall
echo 'Done'
